Connection Backends
===================

.. module:: nxt.backend

Backends are used by :func:`nxt.locator.find`. You will usually not use them
directly.

USB
---

.. automodule:: nxt.backend.usb
   :members:

Bluetooth
---------

.. automodule:: nxt.backend.bluetooth
   :members:

Device file
-----------

.. automodule:: nxt.backend.devfile
   :members:

Socket
------

.. automodule:: nxt.backend.socket
   :members:
